==> gmfsk_0.3.orig.tar.gz: gmfsk-0.3/src/callbacks.h <==
#include <gnome.h>

#include "waterfall.h"
#include "scope.h"

void
on_exit1_activate                      (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_preferences1_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_about1_activate                     (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

gboolean
on_waterfall_motion_notify_event       (GtkWidget       *widget,
                                        GdkEventMotion  *event,
                                        gpointer         user_data);

gboolean
on_waterfall_button_press_event        (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

void
on_freqspinbutton_changed              (GtkEditable     *editable,
                                        gpointer         user_data);

gboolean
on_appwindow_delete_event              (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_afcbutton_toggled                   (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

gboolean
on_bitshapedarea_configure_event       (GtkWidget       *widget,
                                        GdkEventConfigure *event,
                                        gpointer         user_data);

gboolean
on_bitshapedarea_expose_event          (GtkWidget       *widget,
                                        GdkEventExpose  *event,
                                        gpointer         user_data);

gboolean
on_waterfall_leave_notify_event        (GtkWidget       *widget,
                                        GdkEventCrossing *event,
                                        gpointer         user_data);

void
on_macrobutton_clicked                 (GtkButton       *button,
                                        gpointer         user_data);


gboolean
on_macrobutton_button_press_event      (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

gboolean
on_macrobutton_button_press_event      (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

void
on_macroconfigclear_clicked            (GtkButton       *button,
                                        gpointer         user_data);

void
on_macroconfigok_clicked               (GtkButton       *button,
                                        gpointer         user_data);

void
on_macroconfigcancel_clicked           (GtkButton       *button,
                                        gpointer         user_data);

void
on_propertybox_apply                   (GnomePropertyBox *gnomepropertybox,
                                        gint             arg1,
                                        gpointer         user_data);

gboolean
on_appwindow_key_press_event           (GtkWidget       *widget,
                                        GdkEventKey     *event,
                                        gpointer         user_data);

void
on_pausebutton_toggled                 (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_rxbutton_toggled                    (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_txbutton_toggled                    (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_abortbutton_clicked                 (GtkButton       *button,
                                        gpointer         user_data);

void
on_squelchbutton_toggled               (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

gboolean
on_rxtext_button_press_event           (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

void
on_callsign1_activate                  (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_qth1_activate                       (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

gboolean
on_txtext_key_press_event              (GtkWidget       *widget,
                                        GdkEventKey     *event,
                                        gpointer         user_data);

void
on_logbutton_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

void
on_newbutton_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

void
on_name1_activate                      (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_received_rst1_activate              (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_sent_rst1_activate                  (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_notes1_activate                     (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_band1_activate                      (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_qsoentry_changed                    (GtkEditable     *editable,
                                        gpointer         user_data);

void
on_rxclearbutton_clicked               (GtkButton       *button,
                                        gpointer         user_data);

void
on_txclearbutton_clicked               (GtkButton       *button,
                                        gpointer         user_data);


gboolean
on_macroconfigwindow_delete_event      (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_tunebutton_pressed                  (GtkButton       *button,
                                        gpointer         user_data);

void
on_tunebutton_released                 (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_txtext_button_press_event           (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

void
on_txtext_selection_received           (GtkWidget       *widget,
                                        GtkSelectionData *data,
                                        guint            time,
                                        gpointer         user_data);

void
on_send_file1_activate                 (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_fileselect_ok_button_clicked        (GtkButton       *button,
                                        gpointer         user_data);

void
on_fileselect_cancel_button_clicked    (GtkButton       *button,
                                        gpointer         user_data);

void
on_log_to_file1_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_stop_logging1_activate              (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_clear_tx_window1_activate           (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_clear_rx_window1_activate           (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_macroconfig1_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_macroconfig2_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_macroconfig3_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_macroconfig4_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_macroconfig5_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_macroconfig6_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_macroconfig7_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_macroconfig8_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_macroconfig9_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_macroconfig10_activate              (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_macroconfig11_activate              (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_macroconfig12_activate              (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

gboolean
on_txfileselection_delete_event        (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_txfileselect_ok_button_clicked      (GtkButton       *button,
                                        gpointer         user_data);

void
on_txfileselect_cancel_button_clicked  (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_rxfileselection_delete_event        (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_rxfileselect_ok_button_clicked      (GtkButton       *button,
                                        gpointer         user_data);

void
on_rxfileselect_cancel_button_clicked  (GtkButton       *button,
                                        gpointer         user_data);

==> gmfsk-0.4.1.tar.gz: gmfsk-0.4.1/src/callbacks.h <==
#include <gnome.h>

#include "waterfall.h"
#include "scope.h"

/* ---------------------------------------------------------------------- */

/*
 * These are actually in syncscope.c
 */

gboolean
on_syncscope_darea_configure_event       (GtkWidget       *widget,
                                          GdkEventConfigure *event,
                                          gpointer         user_data);

gboolean
on_syncscope_darea_expose_event          (GtkWidget       *widget,
                                          GdkEventExpose  *event,
                                          gpointer         user_data);

gboolean
on_syncscope_darea_button_press_event    (GtkWidget       *widget,
                                          GdkEventButton  *event,
                                          gpointer         user_data);

/* ---------------------------------------------------------------------- */

void
on_exit1_activate                      (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_preferences1_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_about1_activate                     (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

gboolean
on_waterfall_motion_notify_event       (GtkWidget       *widget,
                                        GdkEventMotion  *event,
                                        gpointer         user_data);

gboolean
on_waterfall_button_press_event        (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

void
on_freqspinbutton_changed              (GtkEditable     *editable,
                                        gpointer         user_data);

gboolean
on_appwindow_delete_event              (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_afcbutton_toggled                   (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

gboolean
on_waterfall_leave_notify_event        (GtkWidget       *widget,
                                        GdkEventCrossing *event,
                                        gpointer         user_data);

void
on_macrobutton_clicked                 (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_macrobutton_button_press_event      (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

void
on_macroconfigclear_clicked            (GtkButton       *button,
                                        gpointer         user_data);

void
on_macroconfigok_clicked               (GtkButton       *button,
                                        gpointer         user_data);

void
on_macroconfigcancel_clicked           (GtkButton       *button,
                                        gpointer         user_data);

void
on_propertybox_apply                   (GnomePropertyBox *gnomepropertybox,
                                        gint             arg1,
                                        gpointer         user_data);

void
on_pausebutton_toggled                 (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_rxbutton_toggled                    (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_txbutton_toggled                    (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_abortbutton_clicked                 (GtkButton       *button,
                                        gpointer         user_data);

void
on_squelchbutton_toggled               (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

gboolean
on_rxtext_button_press_event           (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

void
on_callsign1_activate                  (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_qth1_activate                       (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

gboolean
on_txtext_key_press_event              (GtkWidget       *widget,
                                        GdkEventKey     *event,
                                        gpointer         user_data);

void
on_logbutton_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

void
on_newbutton_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

void
on_name1_activate                      (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_received_rst1_activate              (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_sent_rst1_activate                  (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_notes1_activate                     (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_band1_activate                      (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_qsoentry_changed                    (GtkEditable     *editable,
                                        gpointer         user_data);

gboolean
on_macroconfigwindow_delete_event      (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

gboolean
on_txtext_button_press_event           (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

void
on_txtext_selection_received           (GtkWidget       *widget,
                                        GtkSelectionData *data,
                                        guint            time,
                                        gpointer         user_data);

void
on_send_file1_activate                 (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_log_to_file1_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_stop_logging1_activate              (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_clear_tx_window1_activate           (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_clear_rx_window1_activate           (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_macroconfig1_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_macroconfig2_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_macroconfig3_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_macroconfig4_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_macroconfig5_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_macroconfig6_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_macroconfig7_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_macroconfig8_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_macroconfig9_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_macroconfig10_activate              (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_macroconfig11_activate              (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_macroconfig12_activate              (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

gboolean
on_txfileselection_delete_event        (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_txfileselect_ok_button_clicked      (GtkButton       *button,
                                        gpointer         user_data);

void
on_txfileselect_cancel_button_clicked  (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_rxfileselection_delete_event        (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_rxfileselect_ok_button_clicked      (GtkButton       *button,
                                        gpointer         user_data);

void
on_rxfileselect_cancel_button_clicked  (GtkButton       *button,
                                        gpointer         user_data);

void
on_tunebutton_toggled                  (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_mfsk1_activate                      (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_rtty1_activate                      (GtkMenuItem     *menuitem,
                                        gpointer         user_data);


void
on_throb1_activate                     (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_throb2_activate                     (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_throb4_activate                     (GtkMenuItem     *menuitem,
                                        gpointer         user_data);


void
on_reversebutton_toggled               (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_mag1button_toggled                  (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_mag2button_toggled                  (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_mag4button_toggled                  (GtkToggleButton *togglebutton,
                                        gpointer         user_data);
